==> react-native-svg-asset-plugin-0.1.0.tgz: package/lib/index.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const sharp = require('sharp');

const fs = require('fs');

const imageScales = [{
  scale: 1,
  suffix: ''
}, {
  scale: 2,
  suffix: '@2x'
}, {
  scale: 3,
  suffix: '@3x'
}];

async function reactNativeSvgAssetPlugin(assetData) {
  if (assetData.type === 'svg') {
    return convertSvg(assetData);
  } else {
    return assetData;
  }
}

async function convertSvg(assetData) {
  if (assetData.scales.length !== assetData.files.length) {
    throw new Error("Passed scales doesn't match passed files.");
  } else if (assetData.files.length === 0) {
    throw new Error('No files passed.');
  } else if (assetData.files.length > 1) {
    throw new Error('Multiple SVG scales not supported.');
  } else if (assetData.scales[0] !== 1) {
    throw new Error('Scaled SVGs not supported.');
  }

  const inputFilePath = assetData.files[0];
  const inputFileScale = assetData.scales[0];
  const imageData = await readSvg(inputFilePath);
  const outputImages = await Promise.all(imageScales.map(imageScale => generatePng(imageData, imageScale.scale / inputFileScale, `${assetData.fileSystemLocation}/${assetData.name}${imageScale.suffix}.png`)));
  return _objectSpread({}, assetData, {
    width: imageData.metadata.width,
    height: imageData.metadata.height,
    files: outputImages.map(outputImage => outputImage.filePath),
    scales: outputImages.map(outputImage => outputImage.scale),
    type: 'png'
  });
}

async function readSvg(inputFilePath) {
  const fileBuffer = await new Promise((resolve, reject) => fs.readFile(inputFilePath, (err, data) => err ? reject(err) : resolve(data)));
  const metadata = await sharp(fileBuffer).metadata();
  return {
    buffer: fileBuffer,
    metadata: metadata
  };
}

async function generatePng(inputFile, scale, outputFilePath) {
  if (inputFile.metadata.density === undefined) {
    throw new Error('Input image missing density information');
  }

  await sharp(inputFile.buffer, {
    density: inputFile.metadata.density * scale
  }).png({
    adaptiveFiltering: false,
    compressionLevel: 9
  }).toFile(outputFilePath);
  return {
    filePath: outputFilePath,
    scale: scale
  };
}

const assetDataPlugin = reactNativeSvgAssetPlugin;
module.exports = assetDataPlugin;

==> react-native-svg-asset-plugin-0.1.2.tgz: package/lib/index.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const fse = require('fs-extra');

const path = require('path');

const sharp = require('sharp');

const cacheDirName = '.png-cache';
const imageScales = [{
  scale: 1,
  suffix: ''
}, {
  scale: 2,
  suffix: '@2x'
}, {
  scale: 3,
  suffix: '@3x'
}]; // First run might cause a xmllib error, run safe warmup
// See https://github.com/lovell/sharp/issues/1593

async function warmupSharp(sharp) {
  try {
    await sharp(Buffer.from(`<svg xmlns="http://www.w3.org/2000/svg"><rect width="1" height="1" /></svg>`, 'utf-8')).metadata();
  } catch (_unused) {}

  return sharp;
}

const asyncWarmSharp = warmupSharp(sharp);

async function reactNativeSvgAssetPlugin(assetData) {
  if (assetData.type === 'svg') {
    return convertSvg(assetData);
  } else {
    return assetData;
  }
}

async function convertSvg(assetData) {
  if (assetData.scales.length !== assetData.files.length) {
    throw new Error("Passed scales doesn't match passed files.");
  } else if (assetData.files.length === 0) {
    throw new Error('No files passed.');
  } else if (assetData.files.length > 1) {
    throw new Error('Multiple SVG scales not supported.');
  } else if (assetData.scales[0] !== 1) {
    throw new Error('Scaled SVGs not supported.');
  }

  const inputFilePath = assetData.files[0];
  const inputFileScale = assetData.scales[0];
  const outputDirectory = path.join(assetData.fileSystemLocation, cacheDirName);
  const outputName = `${assetData.name}:${assetData.hash}`;
  const [imageData, _] = await Promise.all([readSvg(inputFilePath), fse.ensureDir(outputDirectory)]);
  const outputImages = await Promise.all(imageScales.map(imageScale => generatePng(imageData, imageScale.scale / inputFileScale, path.join(outputDirectory, `${outputName}${imageScale.suffix}.png`))));
  return _objectSpread({}, assetData, {
    fileSystemLocation: outputDirectory,
    httpServerLocation: `${assetData.httpServerLocation}/${cacheDirName}`,
    width: imageData.metadata.width,
    height: imageData.metadata.height,
    files: outputImages.map(outputImage => outputImage.filePath),
    scales: outputImages.map(outputImage => outputImage.scale),
    name: outputName,
    type: 'png'
  });
}

async function readSvg(inputFilePath) {
  const fileBuffer = await fse.readFile(inputFilePath);
  const warmSharp = await asyncWarmSharp;
  const metadata = await warmSharp(fileBuffer).metadata();
  return {
    buffer: fileBuffer,
    metadata: metadata
  };
}

async function generatePng(inputFile, scale, outputFilePath) {
  if (inputFile.metadata.density === undefined) {
    throw new Error('Input image missing density information');
  }

  const density = inputFile.metadata.density;
  const warmSharp = await asyncWarmSharp;
  await warmSharp(inputFile.buffer, {
    density: density * scale
  }).png({
    adaptiveFiltering: false,
    compressionLevel: 9
  }).toFile(outputFilePath);
  return {
    filePath: outputFilePath,
    scale: scale
  };
}

const assetDataPlugin = reactNativeSvgAssetPlugin;
module.exports = assetDataPlugin;
